#pragma rtGlobals=1		// Use modern global access method.

-----------------------------------------------------------------------
//
//	Add_Offsets() adds the ccsf-a depths to the third layer of the Coring_Matrix
//
//		Cut & Paste the Offsets column from the correlation table in the Site Report (or revised).
//		Rename as U1338A_Offsets.
//
//		Note: This macro uses the point numbers of the offsets wave as core numbers, so you need
//		to insert a blank value at the top of the wave in position 0. Also check to be sure that no
//		cores were skipped in the table. Sometimes cores with no recovery are not listed in the 
//		offset table.
//
	
	Function Add_Offsets_2_Matrix()
		SetDataFolder root:
			String/G G_Hole
			String Hole = G_Hole
			G_Hole = Hole
			Prompt Hole, "Hole:"
			DoPrompt "Add_Offsets_2_Matrix", Hole; AbortOnValue V_Flag, 0
			Add_Offsets_2_Matrix_F( Hole )
			Print "Add_Offsets_2_Matrix_F( \"" + Hole + "\" )"
	End
	
	--------------------------------------------------------------------
	
	Function Add_Offsets_2_Matrix_F( Hole )
		String Hole
		SetDataFolder root:
			String/G G_Hole
			Variable i = 0
			G_Hole = Hole	
			If( !Exists( Hole + "_Coring_Matrix" ) || !Exists( Hole + "_Offsets" ) )
				ABORT "Missing either a Coring_Matrix or Offset wave for Hole " + Hole
			EndIf
			CheckOffsets_CoreNumbers( Hole ) // This warns if the offsets and core numbers are not the same. Sometimes offsets for cores with no recovery are skipped in tables.
			WAVE Matrix = $Hole + "_Coring_Matrix", Offsets = $Hole + "_Offsets"
			Note/K Matrix, note( Offsets )
			Matrix[ ][ ][ 2 ] = Matrix[ p ][ q ][ 0 ]
			Redimension/N = ( dimsize( Matrix, 0 ) ) Offsets
			Do
				Matrix[i][ ][2] += Offsets[i]
				i += 1
			While( i < NumPnts( Offsets ) )
	End
		
