﻿#pragma TextEncoding = "UTF-8"		// For details execute DisplayHelpTopic "The TextEncoding Pragma"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// Changed 6/17/2017 to add splice_format to the SpliceDataCheck routine
// Changed 10/9/2017 to fix bug that didn't filter out holes that are not part of the splice, which were making "ghost" axes
	
	Function Calculate_Splice_Lines( ) 
		SetDataFolder root:
			String/G G_Site, G_Splice_Format
			String Site = G_Site, Splice_Format = G_Splice_Format, S_Hole, HoleLetter
			Variable i
			Prompt Site, "Site"
			Prompt Splice_Format,  "Use Splice Ties or Splice Intervals Format?",  popup,  "Splice_Intervals;Splice_Ties"
			DoPrompt "Calculate_Splice_Lines", Site, Splice_Format; AbortOnValue V_Flag, 0
			G_Site = Site; G_Splice_Format = Splice_Format
			Calculate_Splice_Lines_F( Site, Splice_Format )
			Print "Calculate_Splice_Lines_F( \"" + Site + "\", \"" + Splice_Format + "\" )"
	End 
		
	Function Calculate_Splice_Lines_F( Site, Splice_Format ) 
			String Site, Splice_Format
		SetDataFolder root:
			String S_Hole, HoleLetter
			Variable i
			If( SpliceDataCheck( Site, Splice_Format ) ) // This is a separate function to check the splice tables, both intervals and ties.
				Abort
			Endif
			PauseUpdate;
		SetDataFolder $"root:" + Site + "_" + Splice_Format
			WAVE/Z/T Hole_Top, Hole_Bottom
			WAVE/Z CCSF_Top, CCSF_Bottom
			String PossibleHoles = "A;B;C;D;E;F;G;H;I;J;K;L;M;N;O;P;Q;R;S;T;U;V;W;X;Y;Z" // List of all possible hole letters for use in followig loop
			String HoleLetterList = " " // Initializes the list of hole letters with a blank
			For( i = 0; i < ItemsInList( PossibleHoles ); i += 1 ) // This loop makes a list of holes ( hole letters ) from the splice tie or splice interval waves
				FindValue/TEXT = StringFromList( i, PossibleHoles ) Hole_Top
				If( V_Value > -1 )
					HoleLetterList =  StringFromList( i, PossibleHoles ) + ";" + HoleLetterList
				EndIf
			EndFor
			HoleLetterList = RemoveEnding( HoleLetterList ) // These 2 lines get rid of the ";" and blank at the end of the hole letter list
			HoleLetterList = RemoveEnding( HoleLetterList )
		NewDataFolder/O/S $"root:" + Site + "_Splice_Lines"
			Duplicate/O CCSF_Top Top_CCSF // Top_CCSF is created so that a 0 can be added to the top when splice ties are used, thus lining up tops and bottom depths of splice intervals
			Duplicate/O CCSF_Bottom Splice_Point_Value
			If( StringMatch( "Splice_Intervals", Splice_Format ) )
				Duplicate/O/T Hole_Top Top_Holes
			Else
				Duplicate/O/T Hole_Bottom Top_Holes
				InsertPoints 0, 1, Top_CCSF
			EndIf
			Splice_Point_Value = 1		
			For( i = 0; i < ItemsInList( HoleLetterList ); i += 1 ) // This loop fills in the depths for the tops and bottoms of the splice intervals on Hole at a time
				HoleLetter = StringFromList( i, HoleLetterList )
				S_Hole = Site + HoleLetter
				Duplicate/O CCSF_Bottom Mask
				Mask = StringMatch( Top_Holes, HoleLetter ) ? 1 : NaN
				Mask *= CCSF_Bottom
				Duplicate/O Mask $S_Hole + "_Bottom"
				Duplicate/O Top_CCSF Mask
				Mask = StringMatch( Top_Holes, HoleLetter ) ? 1 : NaN
				Mask *= Top_CCSF
				Duplicate/O Mask $S_Hole+ "_Top"
			EndFor
			KillWaves/Z Mask, Bottom_Holes, Bottom_CCSF, Top_Holes, Top_CCSF;
		SetDataFolder root:	
	End
	
	





//	Function Calculate_Splice_Lines( ) // Old version 09OCT2017
		SetDataFolder root:
			String/G G_Site, G_Splice_Format
			String Site = G_Site, Splice_Format = G_Splice_Format, Image_Folders, Folder, S_Hole, HoleLetter
			Variable i = 0, FirstU;
			Prompt Site, "Site"
			Prompt Splice_Format,  "Use Splice Ties or Splice Intervals Format?",  popup,  "Splice_Intervals;Splice_Ties"
			DoPrompt "Calculate_Splice_Lines", Site, Splice_Format; AbortOnValue V_Flag, 0
			G_Site = Site; G_Splice_Format = Splice_Format
			If( SpliceDataCheck( Site, Splice_Format ) ) // This is a separate function to check the splice tables, both intervals and ties.
				Abort
			Endif
			PauseUpdate;
			Image_Folders = FolderList( "S2" )
		SetDataFolder $"root:" + Site + "_" + Splice_Format
			WAVE/T Hole_Top, Hole_Bottom
			WAVE CCSF_Top, CCSF_Bottom
		NewDataFolder/O/S $"root:" + Site + "_Splice_Lines"
			Duplicate/O CCSF_Bottom Bottom_CCSF
			Duplicate/O CCSF_Top Top_CCSF
			Duplicate/O Bottom_CCSF Splice_Point_Value
			If( StringMatch( "Splice_Intervals", Splice_Format ) )
				Duplicate/O/T Hole_Top Bottom_Holes, Top_Holes
			Else
				Duplicate/O/T Hole_Bottom Bottom_Holes, Top_Holes
				InsertPoints 0, 1, Top_CCSF
			EndIf
			Splice_Point_Value = 1		
			For( i = 0; i < ItemsInList( Image_Folders ); i += 1 )
				Folder = StringFromList( i, Image_Folders )
				S_Hole = DataWaveHole( Folder )
				HoleLetter = S_Hole[ StrLen( S_Hole ) - 1 ]
				Duplicate/O Bottom_CCSF Mask
				Mask = StringMatch( Top_Holes, HoleLetter ); Mask -= 1; Mask = Sqrt( Mask ); Mask += 1
				Mask *= Bottom_CCSF
				Duplicate/O Mask $S_Hole + "_Bottom"
				Duplicate/O Top_CCSF Mask
				Mask = ( StringMatch( Top_Holes, HoleLetter ) ); Mask -= 1; Mask = Sqrt(Mask); Mask += 1
				Mask *= Top_CCSF
				Duplicate/O Mask $S_Hole+ "_Top"
			EndFor
			KillWaves/Z Mask, Bottom_Holes, Bottom_CCSF, Top_Holes, Top_CCSF;
		SetDataFolder root:	
	End
	
