﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

// This function checks to see that the depths of bottoms of sections are equal to depths at the top of the next deeper sections
// Mismatches, if any, are printed to History. Otherwise a message is printed stating that the math is correct.

	Function CheckMatrixDepths( )
		SetDataFolder root:
			String/G G_Hole
			String Hole = G_Hole
			Prompt Hole, "Hole:"
			DoPrompt "CheckMatrixDepths", Hole; AbortOnValue V_Flag, 0
			G_Hole = Hole
			CheckMatrixDepths_F( Hole )
			Print "CheckMatrixDepths_F( \"" + Hole + "\" )"
	End


	Function CheckMatrixDepths_F( Hole )
			String Hole
			Variable i, j, k = 0
		SetDataFolder root:
			WAVE Matrix = $Hole + "_Coring_Matrix"
			Make/O /N = ( DimSize( Matrix, 1 ) ) CSF, Length, CSF2
			String AlertMsg1 = "\tBottom CSF of Core "
			String AlertMsg2 = ") does not equal the top of the next section."
			For( j = 1; j < DimSize( Matrix, 0 ); j += 1 )
				CSF = Matrix[ j ][ p ][ 0 ]
				Length = Matrix[ j ][ p ][ 1 ]
				CSF2 = CSF + Length
				Sort CSF,CSF,CSF2,Length
				For( i = 1; i < NumPnts( CSF ); i += 1 )
					If( !NumType( CSF[ i ] ) )
						If( ABS( CSF[ i ] - CSF2[ i - 1 ] ) > .005 )
							Print AlertMsg1 + Num2Str( j ) + " Sec " + Num2Str( i ) + " (" + Num2Str(CSF2[ i - 1 ]) + AlertMsg2 + " (" + Num2Str(CSF[ i ]) + ")"
							k = 1
						Endif
					Else
						Break
					Endif
				EndFor
			EndFor			
			If( k )
				String AlertMsg3 = "There are instances where the bottom CSF of a section "
				String AlertMsg4 = "does not equal the top depth of the next section. Check the HISTORY printout.\r\r"				
				String AlertMsg5 = "Use the function \"CheckMatrixDepths( Hole )\" to check corrections."
				DoAlert/T = "Coring Matrix Problem" 0, AlertMsg3 + AlertMsg4 + AlertMsg5
			Else
				DoAlert/T = "Coring Matrix O.K" 0, "There are no addition errors in the data loaded into the coring matrix."
			EndIf	
			KillWaves/Z CSF, CSF2, Length
	End
	
	
