﻿#pragma TextEncoding = "UTF-8"
#pragma rtGlobals=3		// Use modern global access method and strict wave access.

	Function CursorA_DataFilter()
		SetDataFolder root:
			Variable/G G_FilterWidth
			Variable CenterFreq = XCsr( A ), FilterWidth = G_FilterWidth, i
			String DataWave = StringByKey( "CWaveDF", AxisInfo( "", "DataAxis" ) ) + StringByKey( "CWave", AxisInfo( "", "DataAxis" ) )
			If( !StringMatch( CsrWave( A ), "NMatrix" ) ) // Check to be sure that the A cursor is on the spectrogram and not a contour of some other element of the graph
				ABORT "Cursor A is not on the NMatrix spectrogram. It might be on one of the contours instead, or not on the image at all."
			EndIf
			Prompt FilterWidth, "Filter Width ( +/- % of Center Frequency )", popup, "30;60"
			DoPrompt "CursorA_DataFilter", FilterWidth
			G_FilterWidth = FilterWidth; AbortOnValue V_Flag, 0
			WAVE DataWv = $DataWave
			Duplicate/O DataWv TaperedDataWv
			FilterWidth *= .3 // This works because the popup prompt for Variables returns the number of the selection e.g. 1 or 2 rather than the value
			Make/O/N = ( NumPnts( DataWv ) ) DataTaperMask // A mask is created to taper the ends of the data to 0 and avoid end effects on the spectrum
			DataTaperMask = 1
			Variable TaperLength = .01 * NumPnts( DataWv ) // The first and last ~2% of the data will be tapered
			DataTaperMask[ 0, TaperLength ] = 0 // First 2% of data are set to 0
			DataTaperMask[ NumPnts( DataWv ) - TaperLength, inf ] = 0 // Last 2% of data are set to 0
			Smooth ( 0.5 * NumPnts( DataWv ) ), DataTaperMask // The Mask is smoothed such that it smoothly varies between 1 and 0 at each end
			TaperedDataWv *= DataTaperMask // The data are multiplied by the mask

			For( i = 0; 1; i += 1 ) // Pad the tapered data to the next highest power of 2
				If( 2^i > NumPnts( DataWv ) ) // Compare 2 to the power of i with the number of data points
					ReDimension/N = ( 2^i ) TaperedDataWv // When 2^i exceeds the number of data points, extend the wave to that power of 2
					Break // This breaks out of the loop because the condition has been met
				EndIf
			EndFor

			FFT/OUT = 1/DEST = $"DataWave" + "_FFT" TaperedDataWv // FFT of data
			FFT/OUT = 3/DEST = $"DataWave" + "_PWR" TaperedDataWv	// Power spectrum of data
			WAVE/C DataWvFFT = $"DataWave" + "_FFT" // Declare the FFT wave as complex 
			Variable LowerLimit = CenterFreq - ( FilterWidth * CenterFreq ) // Set the top and bottom of the filter window based on center and width
			Variable UpperLimit = CenterFreq + ( FilterWidth * CenterFreq )
			DataWvFFT[ 0, X2Pnt( DataWvFFT, LowerLimit ) ] = 0 // Zero out frequencies outside the filter window
			DataWvFFT[ X2Pnt( DataWvFFT, UpperLimit ), inf ] = 0
			IFFT/DEST = $DataWave + "_Filtered" DataWvFFT // Create the filtered wave	
			WAVE FilteredData = $DataWave + "_Filtered" // Set wave ref for filtered data
			ReDimension/N = ( NumPnts( DataWv ) ) FilteredData // Get rid of the padding to the power of 2 in the final result
			If( StrSearch( TraceNameList( "", ";", 1 ), NameOfWave( FilteredData ), 0 ) < 0 && StrSearch( TraceNameList( "", ";", 1 ), "FilteredAge", 0 ) < 0 ) // Check to see if the filtered trace is already plotted
				String AxisPosition =  StringByKey( "AXTYPE", AxisInfo( "", "DataAxis" ) ) // See if the Data axis is on the left or on the bottom
				If( StringMatch( AxisPosition, "left" ) ) // Data Axis is on the left
					AppendToGraph/C=(0,0,0)/L=DataAxis/B=AgeAxis/VERT FilteredData	
				Else // Data Axis is on the bottom
					Duplicate/O FilteredData $StringByKey( "CWaveDF", AxisInfo( "", "DataAxis" ) ) + "FilteredAge" // Need to create a new age wave to plot against the filtered data
					WAVE FilteredAge = $StringByKey( "CWaveDF", AxisInfo( "", "DataAxis" ) ) + "FilteredAge" // WaveRef for new wave
					FilteredAge = x // New wave set to ages of the filtered data
					AppendToGraph/C=(0,0,0)/L=AgeAxis/B=DataAxis FilteredAge vs FilteredData
				EndIf
			EndIf
	End		
