#pragma rtGlobals=3		// Use modern global access method and strict wave access.



*******************************************************************************************************

	Function AddTargets()
		SetDataFolder root:
			String/G G_TargetList	
			String Trace
			Variable ColonLocation, ScaleFactor
			Variable i
			For( i = 0; i < ItemsInList( G_TargetList ); i += 2 ) // This loop removes traces in G_TargetList from the top graph
				ColonLocation = StrSearch( StringFromList( i, G_TargetList ), ":", inf, 1 )
				Trace = StringFromList( i, G_TargetList )[ ColonLocation + 1, inf ]
				RemoveFromGraph/Z $Trace, $Trace + "#1"
			EndFor
			For( i = 0; i < ItemsInList( G_TargetList ); i += 2 ) /// This loop adds traces from G_TargetList to the top graph
				ColonLocation = StrSearch( StringFromList( i, G_TargetList ), ":", inf, 1 )
				Trace = StringFromList( i, G_TargetList )[ ColonLocation + 1, inf ]				
				WaveStats/Q $StringFromList( i, G_TargetList )
				ScaleFactor = 1 / Max( Abs( V_Min ), Abs( V_Max ) )
				AppendToGraph/R=Target/T=Age $StringFromList( i, G_TargetList ) vs $StringFromList( i + 1, G_TargetList )
				ModifyGraph muloffset( $Trace ) = { 0, ScaleFactor }
				AppendToGraph/R=TargetUnderlay/T=Age $StringFromList( i, G_TargetList ) vs $StringFromList( i + 1, G_TargetList )
				ModifyGraph muloffset( $Trace#1 ) = { 0, ScaleFactor }
			EndFor
			ModifyGraph freePos = 0	
			ModifyGraph axisEnab( Target )={ 0.33, 0.66 }	
			ModifyGraph axisEnab( TargetUnderlay )={ 0.66, 1 }	
	End

	Function TuningDataSetUp()
		SetDataFolder root:
			String/G G_YorN
			String YorN = G_YorN
			NewDataFolder/O Xtras
			If( !Exists( "DepthTies" ) )  // Check to see if there are depth ties already established
				Make/O/N = 0 DepthTies, AgeTies  // If there are no ties, establish empty Tie waves
			Endif
			WAVE AgeTies, DepthTies	
		SetDataFolder root:
			String/G G_DataFolder, G_DataWave, G_DepthWave 
			String DataWave = G_DataWave, DepthWave = G_DepthWave
			String DataFolder = G_DataFolder
			Prompt DataFolder "Data Folder", popup, FolderList( "*" )
			DoPrompt "TuningDataSetUp", DataFolder						// Select then Folder holding the data to be tuned
			G_DataFolder = DataFolder;
			AbortOnValue V_Flag, 0
		SetDataFolder $DataFolder								// Make the data folder the active folder
			Prompt DataWave, "Data Wave", popup, WaveList( "*", ";", "" )
			Prompt DepthWave, "Depth Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "TuningDataSetUp", DataWave, DepthWave		// Select the data and depth waves
			G_DataWave = DataWave; G_DepthWave = DepthWave
			AbortOnValue V_Flag, 0
			WAVE DDepthWv = $DepthWave, DWv = $DataWave
			String DataAge = FirstPart( DataWave ) + "_" + SecondPart( DataWave ) + "_Age" // Create a wave to hold ages for the data points
			Duplicate/O DWv $DataAge // Creates the wave from the name formed above
			WAVE DAge = $DataAge		// Create a ref for the data Age wave
			String DataAxisName = ThirdPart( DataWave )	// Name the Data Axis as the third part of the data wave name
			String GraphName = DataAxisName + "_Tuning"
			String DataAxis4Depth = DataAxisName + "4Depth"  // Name the depth axis as the data axis name plus "4Depth"
							// Now display the data
			Display/W = (454,45,1148,480)/N = $GraphName/B = Depth/L = $DataAxis4Depth $DataWave vs $DepthWave as GraphName
			Label $DataAxis4Depth DataAxisName
			ShowInfo
			ModifyGraph freePos = 0	
			ModifyGraph axisEnab( $DataAxis4Depth )={ 0.0, 0.33 }	// data vs depth are plotted in the bottom third of the graph
			ModifyGraph lblPos($DataAxis4Depth) = 40	
		SetDataFolder root:
			String/G G_AgeModelAge, G_AgeModelDepth, G_AgeModelFolder
			String AgeModelAge = G_AgeModelAge, AgeModelDepth = G_AgeModelDepth, AgeModelFolder = G_AgeModelFolder
			Prompt AgeModelFolder, "Age Model Folder", popup, FolderList( "*" )
			DoPrompt "TuningDataSetUp", AgeModelFolder   		// Select the Age Model folder
			G_AgeModelFolder = AgeModelFolder	
			AbortOnValue V_Flag, 0
			SetDataFolder $AgeModelFolder	//  Move to the age model folder
			Prompt AgeModelAge, "Age Wave", popup, WaveList( "*", ";", "" )
			Prompt AgeModelDepth, "Depth Wave", popup, WaveList( "*", ";", "" )
			Prompt YorN, "Add Age Model To Ties?  Don't Do This More Than 1 Time For An Experiment Or The Age Points Will Be Duplicated", popup, "No;Yes"
			DoPrompt "TuningDataSetUp", AgeModelAge, AgeModelDepth, YorN			// Select the depth and age waves
			G_AgeModelAge = AgeModelAge; G_AgeModelDepth = AgeModelDepth; G_YorN = YorN
			WAVE AgeModelAgeRef = $AgeModelAge, AgeModelDepthRef = $AgeModelDepth
			AbortOnValue V_Flag, 0
		NewDataFolder/O/S root:Xtras:OriginalModel
			String MDepthValStr = "MDepthVal_" + DataAxisName
			Duplicate/O AgeModelAgeRef MAgeValWv, $MDepthValStr, MNumbers
			WAVE MDepthValWv = $MDepthValStr
			MNumbers = x  // MNumbers are the point numbers for the age model data points
			MAgeValWv = 1
			MDepthValWv = interp( AgeModelDepthRef, DDepthWv, DWv )	// Calculate Data values for age model depths				
			AddTargets()
			AppendToGraph/R = TieAxis/T = Age MAgeValWv vs AgeModelAgeRef
			SetAxis TieAxis, 0, 1.2
			ModifyGraph tick(TieAxis)=3,noLabel(TieAxis)=2,axisEnab(TieAxis)={0.33,0.75},freePos(TieAxis)=0
			ModifyGraph mode(MAgeValWv)=1,rgb(MAgeValWv)=(0,0,65535)
			AppendToGraph/T = Age/R = TieAxis MAgeValWv vs AgeModelAgeRef
			ModifyGraph mode(MAgeValWv#1)=3,rgb(MAgeValWv#1)=(3,52428,1),textMarker(MAgeValWv#1)={:Xtras:OriginalModel:MNumbers,"default",0,0,9,0.00,10.00}
			AppendToGraph/B = Depth/L = $DataAxis4Depth MDepthValWv vs AgeModelDepthRef
			AppendToGraph/B = Depth/L = $DataAxis4Depth MDepthValWv vs AgeModelDepthRef
			ModifyGraph mode($MDepthValStr)=3,mrkThick($MDepthValStr)=2,rgb($MDepthValStr)=(3,52428,1), mode($MDepthValStr + "#1")=3
			ModifyGraph rgb($MDepthValStr + "#1")=(3,52428,1),textMarker($MDepthValStr + "#1")={:Xtras:OriginalModel:MNumbers,"default",0,0,5,0.00,10.00}
		SetDataFolder root:
			If( StringMatch( YorN, "Yes" ) )
				Concatenate/NP { AgeModelAgeRef }, AgeTies
				Concatenate/NP { AgeModelDepthRef }, DepthTies
			EndIf	
		NewDataFolder/O/S root:Xtras:TuningVals	
			String DepthValStr = "DepthVals_" + DataAxisName
			Duplicate/O AgeTies AgeVals, $DepthValStr, TieNums
			WAVE DepthVals = $DepthValStr
			TieNums = x
			AgeVals = 1.1
			DepthVals = interp( DepthTies, DDepthWv, DWv )	
		SetDataFolder root:	
			DAge = interp( DDepthWv, DepthTies, AgeTies )
			WaveStats/Q AgeTies
			DAge = DAge > V_Max ? NaN : DAge	

AppendToGraph/L=$DataAxisName + "VsAge"/T=Age DWv vs DAge
ModifyGraph axisEnab($DataAxisName + "VsAge")={0.66,1},freePos($DataAxisName + "VsAge")=0
AppendToGraph/L=$DataAxisName + "VsAge"/T=Age DepthVals vs AgeTies
ModifyGraph mode($DepthValStr)=3,msize($DepthValStr)=5,rgb($DepthValStr)=(0,0,0),textMarker($DepthValStr)={:Xtras:TuningVals:TieNums,"default",0,0,5,0.00,0.00}


AppendToGraph/L=$DataAxis4Depth/B=Depth DepthVals vs DepthTies
ModifyGraph mode($DepthValStr + "#1")=3,msize($DepthValStr + "#1")=5,rgb($DepthValStr + "#1")=(0,0,0),textMarker($DepthValStr + "#1")={:Xtras:TuningVals:TieNums,"default",0,0,5,0.00,0.00}
AppendToGraph/R = TieAxis/T = Age AgeVals vs AgeTies
SetAxis TieAxis, 0, 1.2
ModifyGraph tick(TieAxis)=3,noLabel(TieAxis)=2,axisEnab(TieAxis)={0.33,0.70},freePos(TieAxis)=0
ModifyGraph mode(AgeVals)=1,rgb(AgeVals)=(0,0,65535)
AppendToGraph/T = Age/R = TieAxis AgeVals vs AgeTies
ModifyGraph mode(AgeVals#1)=3,rgb(AgeVals#1)=(3,52428,1),textMarker(AgeVals#1)={:Xtras:TuningVals:TieNums,"default",0,0,9,0.00,10.00}
	
			
		SetDataFolder root:	
	End


	Function Tuning_SetUp( )
		SetDataFolder root:
			String/G G_DFolder, G_TFolder, G_MFolder, G_ModelAge, G_ModelDepth
			String/G G_DataWv, G_DataDepthWv, G_TargetWv, G_TargetAgeWv
			String DataWv = G_DataWv, DataDepthWv = G_DataDepthWv, TargetWv = G_TargetWv, TargetAgeWv = G_TargetAgeWv
			String DFolder = G_DFolder, TFolder = G_TFolder, MFolder = G_MFolder, ModelAge = G_ModelAge, ModelDepth = G_ModelDepth
			Prompt DFolder, "Data Folder", popup, FolderList( "*" ) 		// Select the folder with the data to be tuned
			DoPrompt "Tuning_SetUp", DFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + DFolder									// Move to the data folder
			Prompt DataWv "Data Wave", popup, WaveList( "*", ";", "" )
			Prompt DataDepthWv "Data Depth Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp" DataWv, DataDepthWv; AbortOnValue V_Flag, 0		// Select the data and depth waves
			Wave DWv = $DataWv, DDepthWv = $DataDepthWv					// Make wave refs for data and depth
			G_DataWv = DataWv, G_DataDepthWv = DataDepthWv, G_DFolder = DFolder	
			String DataAge = DataWaveHole( DataWv ) + "_" + DataWaveTechnique( DataWv ) + "_Age" // Create a wave to hold ages for the data points
			Duplicate/O DWv $DataAge // Creates the wave from the name formed above
			WAVE DAge = $DataAge		// Create a ref for the data Age wave
		SetDataFolder root:
			Prompt TFolder, "Target Data Folder", popup, FolderList( "*" ) // Select the Target data folder
			DoPrompt "Tuning_SetUp", TFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + TFolder						// Go to the Target data folder
			Prompt TargetWv, "Target Data Wave", popup, WaveList( "*", ";", "" )
			Prompt TargetAgeWv, "Target Age Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp", TargetWv, TargetAgeWv; AbortOnValue V_Flag, 0 // Select the Target Data and Age waves
			Wave TWv = $TargetWv, TAgeWv = $TargetAgeWv
			G_TargetWv = TargetWv, G_TargetAgeWv = TargetAgeWv, G_TFolder = TFolder
		SetDataFolder root:
			If( !Exists( "DepthTies" ) )  // Check to see if there are depth ties already established
				Make/O/N = 0 DepthTies, AgeTies  // If there are no ties, establish empty Tie waves
			Endif
			WAVE AgeTies, DepthTies	
			Prompt MFolder, "Age Model Folder", popup, FolderList( "*" )	// Select the Age Model folder
			DoPrompt "Tuning_SetUp", MFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + MFolder				// Move to the age model folder	
			Prompt ModelAge, "Model Age Wave", popup, WaveList( "*", ";", "" )
			Prompt ModelDepth, "Model Depth Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp" ModelAge, ModelDepth; AbortOnValue V_Flag, 0 // Select the age and depth waves for the age model
			WAVE MAgeWv = $ModelAge, MDepthWv = $ModelDepth
			G_MFolder = MFolder, G_ModelAge = ModelAge, G_ModelDepth = ModelDepth

					// End of section that sets up wave references for all of the waves involved

			Duplicate/O MAgeWv MAgeValWv, MDepthValWv, MNumbers // Still in Age Model folder, make waves to hold plotting values
			MNumbers = x  // MNumbers are the point numbers for the age model data points
			MAgeValWv = interp( MAgeWv, TAgeWv, TWv )  // Calculate  Target values for age model ages
			MDepthValWv = interp( MDepthWv, DDepthWv, DWv )	// Calculate Data values for age model depths				
			DoAlert/T = "Add Age Model To Ties", 2, "Add  Age Model To Ties?\r  Don't Do This More Than 1 Time For An Experiment\r  Or The Age Points Will Be Duplicated"
			Switch( V_Flag )
				Case 1:  // The age model data points are added to the Tie waves in root
					Concatenate/NP { MAgeWv }, AgeTies
					Concatenate/NP { MDepthWv }, DepthTies		
					Break
				Case 2: // Don't add ties
					Break
				Case 3: // User selected "Cancel"
					Abort
			EndSwitch
		NewDataFolder/O/S root:Xtras	
			Duplicate/O AgeTies AgeVals, DepthVals, TieNums
			TieNums = x
			AgeVals = interp( AgeTies, TAgeWv, TWv )
			DepthVals = interp( DepthTies, DDepthWv, DWv )	
		SetDataFolder root:	
			DAge = interp( DDepthWv, DepthTies, AgeTies )
			WaveStats/Q AgeTies
			DAge = DAge > V_Max ? NaN : DAge	
	
	TuningSedRateCalc( )
	SedRateGraph( )	
			PauseUpdate
		SetDataFolder $DFolder
			Display /W=(513,45,1996,638)/L=Data/B=Depth DWv vs DDepthWv as "Tuning"
			AppendToGraph/L=Target/T=Age TWv vs TAgeWv
			AppendToGraph/L=Target/T=Age MAgeValWv vs MAgeWv
			AppendToGraph/L=Data/B=Depth MDepthValWv vs MDepthWv
			AppendToGraph/L=Target/T=Age ::Xtras:AgeVals vs ::AgeTies
			AppendToGraph/L=Data/B=Depth ::Xtras:DepthVals vs ::DepthTies
			AppendToGraph/L=DataVsAge/T=Age DWv vs DAge
			AppendToGraph/L=DataVsAge/T=Age DepthVals vs AgeTies
		SetDataFolder root:
			ModifyGraph axisEnab(Data)={0,0.33}
			ModifyGraph axisEnab(Target)={0.33,0.66}
			ModifyGraph axisEnab(DataVsAge)={0.66,1}
			ModifyGraph mirror(Data)=2,mirror(Target)=2,mirror(DataVsAge)=2
			ModifyGraph nticks(Depth)=10,nticks(Age)=10
			ModifyGraph minor(Data)=1,minor(Depth)=1,minor(Target)=1,minor(Age)=1
			ModifyGraph freePos(Data)=0
			ModifyGraph freePos(Depth)=0
			ModifyGraph freePos(Target)=0
			Label Target "\\Z12" + TargetWv + "\\u#2"
			ModifyGraph lblPos(Target)=60
			Label Data "\\Z12" + DataWv + "\\u#2"
			ModifyGraph lblPos(Data)=60
			Label DataVsAge "\\u#2"
			ModifyGraph freePos(Age)=0
			ModifyGraph freePos(DataVsAge)=0
			ModifyGraph mode(MAgeValWv)=3,mode(MDepthValWv)=3,mode(AgeVals)=3,mode(DepthVals)=3
			ModifyGraph mode(DepthVals#1)=3
			ModifyGraph marker(MAgeValWv)=42,marker(MDepthValWv)=42			
			ModifyGraph rgb( $DataWv )=(0,0,0), rgb( $TargetWv )=(0,43690,65535),rgb(AgeVals)=(2,39321,1)
			ModifyGraph rgb(DepthVals)=(2,39321,1),rgb(DepthVals#1)=(19675,39321,1)
			ModifyGraph msize(MAgeValWv)=7,msize(MDepthValWv)=7,msize(AgeVals)=7,msize(DepthVals)=7
			ModifyGraph msize(DepthVals#1)=7
			ModifyGraph mrkThick(MAgeValWv)=2,mrkThick(MDepthValWv)=2
			ModifyGraph gaps($DataWv)=0
			ModifyGraph textMarker(MAgeValWv)={ MNumbers,"default",0,0,5,0.00,0.00}
			ModifyGraph textMarker(MDepthValWv)={MNumbers,"default",0,0,5,0.00,0.00}
			ModifyGraph textMarker(AgeVals)={TieNums,"default",1,0,5,0.00,0.00},textMarker(DepthVals)={TieNums,"default",1,0,5,0.00,0.00}
			ModifyGraph textMarker(DepthVals#1)={TieNums,"default",1,0,5,0.00,0.00}
			ShowInfo
			
			TuningAlignTieRange_F( 0, NumPnts( AgeTies ) - 1 )
	End


//	Function Tuning_SetUp( )
		SetDataFolder root:
			String/G G_DFolder, G_TFolder, G_MFolder, G_ModelAge, G_ModelDepth
			String/G G_DataWv, G_DataDepthWv, G_TargetWv, G_TargetAgeWv
			String DataWv = G_DataWv, DataDepthWv = G_DataDepthWv, TargetWv = G_TargetWv, TargetAgeWv = G_TargetAgeWv
			String DFolder = G_DFolder, TFolder = G_TFolder, MFolder = G_MFolder, ModelAge = G_ModelAge, ModelDepth = G_ModelDepth
			Prompt DFolder, "Data Folder", popup, FolderList( "*" )
			DoPrompt "Tuning_SetUp", DFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + DFolder
			Prompt DataWv "Data Wave", popup, WaveList( "*", ";", "" )
			Prompt DataDepthWv "Data Depth Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp" DataWv, DataDepthWv; AbortOnValue V_Flag, 0
			Wave DWv = $DataWv, DDepthWv = $DataDepthWv
			G_DataWv = DataWv, G_DataDepthWv = DataDepthWv, G_DFolder = DFolder	
			String DataAge = DataWaveHole( DataWv ) + "_" + DataWaveTechnique( DataWv ) + "_Age"
			Duplicate/O DWv $DataAge
			WAVE DAge = $DataAge		
		SetDataFolder root:
			Prompt TFolder, "Target Data Folder", popup, FolderList( "*" )
			DoPrompt "Tuning_SetUp", TFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + TFolder			
			Prompt TargetWv, "Target Data Wave", popup, WaveList( "*", ";", "" )
			Prompt TargetAgeWv, "Target Age Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp", TargetWv, TargetAgeWv; AbortOnValue V_Flag, 0
			Wave TWv = $TargetWv, TAgeWv = $TargetAgeWv
			G_TargetWv = TargetWv, G_TargetAgeWv = TargetAgeWv, G_TFolder = TFolder
		SetDataFolder root:
			If( !Exists( "DepthTies" ) )
				Make/O/N = 0 DepthTies, AgeTies
			Endif
			WAVE AgeTies, DepthTies	
			Prompt MFolder, "Age Model Folder", popup, FolderList( "*" )
			DoPrompt "Tuning_SetUp", MFolder; AbortOnValue V_Flag, 0
		SetDataFolder "root:" + MFolder		
			Prompt ModelAge, "Model Age Wave", popup, WaveList( "*", ";", "" )
			Prompt ModelDepth, "Model Depth Wave", popup, WaveList( "*", ";", "" )
			DoPrompt "Tuning_SetUp" ModelAge, ModelDepth; AbortOnValue V_Flag, 0
			WAVE MAgeWv = $ModelAge, MDepthWv = $ModelDepth
			G_MFolder = MFolder, G_ModelAge = ModelAge, G_ModelDepth = ModelDepth
			Duplicate/O MAgeWv MAgeValWv, MDepthValWv, MNumbers
			MNumbers = x
			MAgeValWv = interp( MAgeWv, TAgeWv, TWv )
			MDepthValWv = interp( MDepthWv, DDepthWv, DWv )					
			DoAlert/T = "Add Age Model To Ties", 2, "Add  Age Model To Ties?\r  Don't Do This More Than 1 Time For An Experiment\r  Or The Age Points Will Be Duplicated"
			Switch( V_Flag )
				Case 1:
					Concatenate/NP { MAgeWv }, AgeTies
					Concatenate/NP { MDepthWv }, DepthTies		
					Break
				Case 2:
					Break
				Case 3:
					Abort
			EndSwitch
		NewDataFolder/O/S root:Xtras	
			Duplicate/O AgeTies AgeVals, DepthVals, TieNums
			TieNums = x
			AgeVals = interp( AgeTies, TAgeWv, TWv )
			DepthVals = interp( DepthTies, DDepthWv, DWv )	
		SetDataFolder root:	
			DAge = interp( DDepthWv, DepthTies, AgeTies )
			WaveStats/Q AgeTies
			DAge = DAge > V_Max ? NaN : DAge	
	
	TuningSedRateCalc( )
	SedRateGraph( )	
			PauseUpdate
		SetDataFolder $DFolder
			Display /W=(513,45,1996,638)/L=Data/B=Depth DWv vs DDepthWv as "Tuning"
			AppendToGraph/L=Target/T=Age TWv vs TAgeWv
			AppendToGraph/L=Target/T=Age MAgeValWv vs MAgeWv
			AppendToGraph/L=Data/B=Depth MDepthValWv vs MDepthWv
			AppendToGraph/L=Target/T=Age ::Xtras:AgeVals vs ::AgeTies
			AppendToGraph/L=Data/B=Depth ::Xtras:DepthVals vs ::DepthTies
			AppendToGraph/L=DataVsAge/T=Age DWv vs DAge
			AppendToGraph/L=DataVsAge/T=Age DepthVals vs AgeTies
		SetDataFolder root:
			ModifyGraph axisEnab(Data)={0,0.33}
			ModifyGraph axisEnab(Target)={0.33,0.66}
			ModifyGraph axisEnab(DataVsAge)={0.66,1}
			ModifyGraph mirror(Data)=2,mirror(Target)=2,mirror(DataVsAge)=2
			ModifyGraph nticks(Depth)=10,nticks(Age)=10
			ModifyGraph minor(Data)=1,minor(Depth)=1,minor(Target)=1,minor(Age)=1
			ModifyGraph freePos(Data)=0
			ModifyGraph freePos(Depth)=0
			ModifyGraph freePos(Target)=0
			Label Target "\\Z12" + TargetWv + "\\u#2"
			ModifyGraph lblPos(Target)=60
			Label Data "\\Z12" + DataWv + "\\u#2"
			ModifyGraph lblPos(Data)=60
			Label DataVsAge "\\u#2"
			ModifyGraph freePos(Age)=0
			ModifyGraph freePos(DataVsAge)=0
			ModifyGraph mode(MAgeValWv)=3,mode(MDepthValWv)=3,mode(AgeVals)=3,mode(DepthVals)=3
			ModifyGraph mode(DepthVals#1)=3
			ModifyGraph marker(MAgeValWv)=42,marker(MDepthValWv)=42			
			ModifyGraph rgb( $DataWv )=(0,0,0), rgb( $TargetWv )=(0,43690,65535),rgb(AgeVals)=(2,39321,1)
			ModifyGraph rgb(DepthVals)=(2,39321,1),rgb(DepthVals#1)=(19675,39321,1)
			ModifyGraph msize(MAgeValWv)=7,msize(MDepthValWv)=7,msize(AgeVals)=7,msize(DepthVals)=7
			ModifyGraph msize(DepthVals#1)=7
			ModifyGraph mrkThick(MAgeValWv)=2,mrkThick(MDepthValWv)=2
			ModifyGraph gaps($DataWv)=0
			ModifyGraph textMarker(MAgeValWv)={ MNumbers,"default",0,0,5,0.00,0.00}
			ModifyGraph textMarker(MDepthValWv)={MNumbers,"default",0,0,5,0.00,0.00}
			ModifyGraph textMarker(AgeVals)={TieNums,"default",1,0,5,0.00,0.00},textMarker(DepthVals)={TieNums,"default",1,0,5,0.00,0.00}
			ModifyGraph textMarker(DepthVals#1)={TieNums,"default",1,0,5,0.00,0.00}
			ShowInfo
			
			TuningAlignTieRange_F( 0, NumPnts( AgeTies ) - 1 )
	End

